Feature Similarity (FSIM)
=========================

.. automodule:: viqa.fr_metrics.fsim
    :exclude-members: FSIM

   
.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.fsim

.. autosummary::
    :toctree: generated/
    :template: class.rst

    FSIM